==> tweaked_graphviz-0.0.5.tar.gz: tweaked_graphviz-0.0.5/setup.py <==

from distutils.core import setup
setup(
  name = 'tweaked_graphviz',         # How you named your package folder (MyLib)
  packages = ['tweaked_graphviz'],   # Chose the same as "name"
  version = '0.0.5',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A tweaked version of an interactive graphviz viewer for Dash',   # Give a short description about your library
  include_package_data=True,
  author = 'Philip Peters',                   # Type in your name
  author_email = 'pcpworld@yahoo.co.uk',      # Type in your E-Mail
  url = 'https://github.com/PhilipPeters/tweaked_graphviz',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/PhilipPeters/tweaked_graphviz/archive/0.0.5.tar.gz',    # I explain this later on
  keywords = ['React', 'Dash', 'Graphviz'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'dash',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)

==> tweaked_graphviz-0.0.7.tar.gz: tweaked_graphviz-0.0.7/setup.py <==
v = 7



#from distutils.core import setup
from setuptools import setup
setup(
  name = 'tweaked_graphviz',         # How you named your package folder (MyLib)
  packages = ['tweaked_graphviz'],   # Chose the same as "name"
  version = '0.0.' + str(v),      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A tweaked version of an interactive graphviz viewer for Dash',   # Give a short description about your library
  include_package_data=True,
  author = 'Philip Peters',                   # Type in your name
  author_email = 'pcpworld@yahoo.co.uk',      # Type in your E-Mail
  url = 'https://github.com/PhilipPeters/tweaked_graphviz',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/PhilipPeters/tweaked_graphviz/archive/0.0.' + str(v) + '.tar.gz',    # I explain this later on
  keywords = ['React', 'Dash', 'Graphviz'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'dash',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)
